@@ -9,7 +9,6 @@
  */
 namespace PHPUnit\Event\Code;
 
-use function count;
 use Iterator;
 
 /**
@@ -41,7 +40,7 @@ final class TestCollectionIterator implements Iterator
 
     public function valid(): bool
     {
-        return $this->position < count($this->tests);
+        return isset($this->tests[$this->position]);
     }
 
     /**
