@@ -9,7 +9,7 @@
  */
 namespace PHPUnit\Framework\MockObject;
 
-use function array_keys;
+use function array_all;
 use function array_map;
 use function explode;
 use function in_array;
@@ -47,9 +47,9 @@ final class ReturnValueGenerator
             $types = explode('|', $returnType);
             $union = true;
 
-            foreach (array_keys($types) as $key) {
-                if (str_starts_with($types[$key], '(') && str_ends_with($types[$key], ')')) {
-                    $types[$key] = substr($types[$key], 1, -1);
+            foreach ($types as $key => $type) {
+                if (str_starts_with($type, '(') && str_ends_with($type, ')')) {
+                    $types[$key] = substr($type, 1, -1);
                 }
             }
         } elseif (str_contains($returnType, '&')) {
@@ -60,7 +60,7 @@ final class ReturnValueGenerator
         }
 
         if (!$intersection) {
-            $lowerTypes = array_map('strtolower', $types);
+            $lowerTypes = array_map(strtolower(...), $types);
 
             if (in_array('', $lowerTypes, true) ||
                 in_array('null', $lowerTypes, true) ||
@@ -164,13 +164,7 @@ final class ReturnValueGenerator
      */
     private function onlyInterfaces(array $types): bool
     {
-        foreach ($types as $type) {
-            if (!interface_exists($type)) {
-                return false;
-            }
-        }
-
-        return true;
+        return array_all($types, static fn (string $type) => interface_exists($type));
     }
 
     /**
@@ -182,7 +176,7 @@ final class ReturnValueGenerator
     private function newInstanceOf(StubInternal $testStub, string $className, string $methodName): Stub
     {
         try {
-            $object    = (new ReflectionClass($testStub::class))->newInstanceWithoutConstructor();
+            $object    = new ReflectionClass($testStub::class)->newInstanceWithoutConstructor();
             $reflector = new ReflectionObject($object);
 
             $reflector->getProperty('__phpunit_state')->setValue(
@@ -218,7 +212,7 @@ final class ReturnValueGenerator
     private function testDoubleFor(string $type, string $className, string $methodName): Stub
     {
         try {
-            return (new Generator)->testDouble($type, false, false, [], [], '', false);
+            return (new Generator)->testDouble($type, false, [], [], '', false);
             // @codeCoverageIgnoreStart
         } catch (Throwable $t) {
             throw new RuntimeException(
