@@ -13,6 +13,7 @@ use function assert;
 use function defined;
 use function get_include_path;
 use function hrtime;
+use function register_shutdown_function;
 use function serialize;
 use function sys_get_temp_dir;
 use function tempnam;
@@ -21,6 +22,7 @@ use function var_export;
 use PHPUnit\Event\NoPreviousThrowableException;
 use PHPUnit\Runner\CodeCoverage;
 use PHPUnit\TextUI\Configuration\Registry as ConfigurationRegistry;
+use PHPUnit\TextUI\Configuration\SourceMapper;
 use PHPUnit\Util\GlobalState;
 use PHPUnit\Util\PHP\Job;
 use PHPUnit\Util\PHP\JobRunnerRegistry;
@@ -35,6 +37,8 @@ use SebastianBergmann\Template\Template;
  */
 final class SeparateProcessTestRunner implements IsolatedTestRunner
 {
+    private static ?string $sourceMapFile = null;
+
     /**
      * @throws \PHPUnit\Runner\Exception
      * @throws \PHPUnit\Util\Exception
@@ -90,7 +94,8 @@ final class SeparateProcessTestRunner implements IsolatedTestRunner
         $includePath             = "'." . $includePath . ".'";
         $offset                  = hrtime();
         $serializedConfiguration = $this->saveConfigurationForChildProcess();
-        $processResultFile       = tempnam(sys_get_temp_dir(), 'phpunit_');
+        $processResultFile       = $this->pathForCachedSourceMap();
+        $sourceMapFile           = $this->sourceMapFileForChildProcess();
 
         $file = $class->getFileName();
 
@@ -117,6 +122,7 @@ final class SeparateProcessTestRunner implements IsolatedTestRunner
             'offsetNanoseconds'              => (string) $offset[1],
             'serializedConfiguration'        => $serializedConfiguration,
             'processResultFile'              => $processResultFile,
+            'sourceMapFile'                  => $sourceMapFile,
         ];
 
         $template = new Template(__DIR__ . '/templates/method.tpl');
@@ -132,21 +138,72 @@ final class SeparateProcessTestRunner implements IsolatedTestRunner
         @unlink($serializedConfiguration);
     }
 
+    private function sourceMapFileForChildProcess(): string
+    {
+        if (self::$sourceMapFile !== null) {
+            return self::$sourceMapFile;
+        }
+
+        if (!ConfigurationRegistry::get()->source()->notEmpty()) {
+            self::$sourceMapFile = '';
+
+            return self::$sourceMapFile;
+        }
+
+        $path = $this->pathForCachedSourceMap();
+
+        if ($path === false) {
+            // @codeCoverageIgnoreStart
+            self::$sourceMapFile = '';
+
+            return self::$sourceMapFile;
+            // @codeCoverageIgnoreEnd
+        }
+
+        if (!SourceMapper::saveTo($path, ConfigurationRegistry::get()->source())) {
+            // @codeCoverageIgnoreStart
+            self::$sourceMapFile = '';
+
+            return self::$sourceMapFile;
+            // @codeCoverageIgnoreEnd
+        }
+
+        register_shutdown_function(static function () use ($path): void
+        {
+            // @codeCoverageIgnoreStart
+            @unlink($path);
+            // @codeCoverageIgnoreEnd
+        });
+
+        self::$sourceMapFile = $path;
+
+        return self::$sourceMapFile;
+    }
+
     /**
      * @throws ProcessIsolationException
      */
     private function saveConfigurationForChildProcess(): string
     {
-        $path = tempnam(sys_get_temp_dir(), 'phpunit_');
+        $path = $this->pathForCachedSourceMap();
 
         if ($path === false) {
+            // @codeCoverageIgnoreStart
             throw new ProcessIsolationException;
+            // @codeCoverageIgnoreEnd
         }
 
         if (!ConfigurationRegistry::saveTo($path)) {
+            // @codeCoverageIgnoreStart
             throw new ProcessIsolationException;
+            // @codeCoverageIgnoreEnd
         }
 
         return $path;
     }
+
+    private function pathForCachedSourceMap(): false|string
+    {
+        return tempnam(sys_get_temp_dir(), 'phpunit_');
+    }
 }
