@@ -12,10 +12,13 @@ namespace PHPUnit\Event\Test;
 use PHPUnit\Event\AbstractEventTestCase;
 use PHPUnit\Event\Code;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 
 #[CoversClass(AfterTestMethodFinished::class)]
 #[Small]
+#[Group('event-system')]
+#[Group('event-system/events')]
 final class AfterTestMethodFinishedTest extends AbstractEventTestCase
 {
     public function testConstructorSetsValues(): void
@@ -32,7 +35,6 @@ final class AfterTestMethodFinishedTest extends AbstractEventTestCase
 
         $this->assertSame($telemetryInfo, $event->telemetryInfo());
         $this->assertSame($test, $event->test());
-        $this->assertSame('FooTest', $event->testClassName());
         $this->assertSame($calledMethods, $event->calledMethods());
     }
 
