@@ -11,6 +11,7 @@ namespace PHPUnit\Framework\Constraint;
 
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Exception;
 use PHPUnit\Framework\ExpectationFailedException;
@@ -19,6 +20,8 @@ use PHPUnit\Framework\TestCase;
 #[CoversClass(ExceptionMessageMatchesRegularExpression::class)]
 #[CoversClass(Constraint::class)]
 #[Small]
+#[Group('framework')]
+#[Group('framework/constraints')]
 final class ExceptionMessageMatchesRegularExpressionTest extends TestCase
 {
     public static function provider(): array
@@ -69,7 +72,7 @@ final class ExceptionMessageMatchesRegularExpressionTest extends TestCase
 
     public function testCanBeRepresentedAsString(): void
     {
-        $this->assertSame('exception message matches \'/.*/\'', (new ExceptionMessageMatchesRegularExpression('/.*/'))->toString());
+        $this->assertSame('exception message matches \'/.*/\'', new ExceptionMessageMatchesRegularExpression('/.*/')->toString());
     }
 
     public function testIsCountable(): void
