@@ -10,21 +10,25 @@
 namespace PHPUnit\TextUI\Configuration;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(Constant::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/value-objects')]
 final class ConstantTest extends TestCase
 {
     public function testHasName(): void
     {
-        $this->assertSame('name', (new Constant('name', 'value'))->name());
+        $this->assertSame('name', new Constant('name', 'value')->name());
     }
 
     public function testHasValue(): void
     {
-        $this->assertSame('value', (new Constant('name', 'value'))->value());
-        $this->assertSame(true, (new Constant('name', true))->value());
+        $this->assertSame('value', new Constant('name', 'value')->value());
+        $this->assertSame(true, new Constant('name', true)->value());
     }
 }
