@@ -10,6 +10,7 @@
 namespace PHPUnit\TextUI\Configuration;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
@@ -18,6 +19,9 @@ use PHPUnit\Framework\TestCase;
 #[CoversClass(ExtensionBootstrapCollectionIterator::class)]
 #[UsesClass(ExtensionBootstrap::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/value-objects')]
 final class ExtensionBootstrapCollectionTest extends TestCase
 {
     public function testIsCreatedFromArray(): void
